aboutsummaryrefslogtreecommitdiff
path: root/node_simple.js
diff options
context:
space:
mode:
authorHumairAK <humair88@hotmail.com>2016-07-25 07:40:26 +0000
committerHumairAK <humair88@hotmail.com>2016-07-25 07:40:26 +0000
commit3d9c04b336c0eade0e15517c0144f44f12ba865f (patch)
tree20af91e006115fdd98731d5fed2c0eebbbc29810 /node_simple.js
parent1032205c1a94ae31d780d2c339abbe628eb27fae (diff)
Accounted for empty comment history in retrieve_userComments_history
Diffstat (limited to 'node_simple.js')
-rw-r--r--node_simple.js22
1 files changed, 13 insertions, 9 deletions
diff --git a/node_simple.js b/node_simple.js
index 0290519..f7da2c3 100644
--- a/node_simple.js
+++ b/node_simple.js
@@ -350,16 +350,20 @@ exports.retrieve_userComments_history = function (username, callback) {
_id: 0
}}
]).toArray(function (err, res) {
- var finised = _.after(res.length, doCall); // execute "doCall" only after res.length # of attempts
- res.forEach(function (comment) {
- exams.find( { _id: ObjectId(comment.exam_id) } ).toArray(function (err, docs) { // get the exam info
- comment.course_code = docs[0].course_code;
- comment.year = docs[0].year;
- comment.term = docs[0].term;
- mylist.push(comment); // save it to array
- finised();
+ if(!res.length){ // Ensure a callback is executed if res is empty
+ callback(true, res);
+ }else{
+ var finised = _.after(res.length, doCall); // execute "doCall" only after res.length # of attempts
+ res.forEach(function (comment) {
+ exams.find( { _id: ObjectId(comment.exam_id) } ).toArray(function (err, docs) { // get the exam info
+ comment.course_code = docs[0].course_code;
+ comment.year = docs[0].year;
+ comment.term = docs[0].term;
+ mylist.push(comment); // save it to array
+ finised();
+ });
});
- });
+ }
});
function doCall() {